import { Component, OnInit } from '@angular/core';
import { UserAnnuary } from '../models/user.model';
import { AuthService } from '../services/auth.service';
import { SearchService } from '../structure-list/services/search.service';
import { SearchQuery, SearchResults } from './models/searchQuery.model';

@Component({
  selector: 'app-annuaire',
  templateUrl: './annuaire.component.html',
  styleUrls: ['./annuaire.component.scss'],
})
export class AnnuaireComponent implements OnInit {
  constructor(private searchService: SearchService, private authService: AuthService) {}
  public userList: UserAnnuary[] = [];
  public searchedValue: string;
  public totalUserResult: number;
  public resetFilters: number = 0;
  public nextPage: number = 1;
  public filterActive: boolean = false;
  public isLoading = true;

  ngOnInit(): void {
    if (!this.userIsLoggedIn()) {
      this.searchService.getUserRegistryCount().subscribe((nb: number) => {
        this.totalUserResult = nb;
      });
      this.isLoading = false;
    }
  }

  public userIsLoggedIn(): boolean {
    return this.authService.isLoggedIn();
  }

  private loadParams(params: SearchQuery): void {
    this.searchService.annuaireSearchQuery = params;
    if (params.employerFilters?.length || params.jobFilters?.length) {
      this.filterActive = true;
    } else {
      this.filterActive = false;
    }
  }

  public searchUsers(params: SearchQuery): void {
    this.loadParams(params);
    this.searchService
      .searchUserRegistry(params.queryParam, params.page, params.jobFilters, params.employerFilters)
      .subscribe((res: SearchResults) => {
        this.userList = res.docs;
        this.totalUserResult = res.count;
        this.isLoading = false;
      });
  }

  public shouldResetFilters(): void {
    this.resetFilters++;
  }
  public showMore(): void {
    this.nextPage++;
  }

  /**
   * Should load in specific conditions such as changes in filters and search input.
   * Should NOT load when showing more result because it would result in losing scroll position because of the rerender of the list.
   */
  public shouldLoad(value: boolean): void {
    this.isLoading = value;
  }
}
