import { Component, Input, OnInit } from '@angular/core';
import { NewsletterService } from '../../services/newsletter.service';
import { NotificationService } from '../../services/notification.service';
import { ButtonType } from '../../shared/components/button/buttonType.enum';

@Component({
  selector: 'app-profile-newsletter',
  templateUrl: './profile-newsletter.component.html',
})
export class ProfileNewsletterComponent implements OnInit {
  @Input() public userEmail: string;
  public buttonTypeEnum = ButtonType;
  public isSubscribed = false;
  public isLoading = true;

  constructor(private newsletterService: NewsletterService, private notificationService: NotificationService) {}

  ngOnInit(): void {
    this.newsletterService.find(this.userEmail).subscribe({
      next: (result) => {
        this.isSubscribed = result !== null;
        this.isLoading = false;
      },
    });
  }

  public handleSubscribe() {
    this.isLoading = true;
    this.newsletterService.subscribe(this.userEmail).subscribe({
      next: (result) => {
        this.notificationService.showSuccess(`L'email ${result.email} a bien été ajouté à la newsletter`);
        this.isSubscribed = true;
        this.isLoading = false;
      },
      error: (error) => {
        if (error.status === 418) {
          this.notificationService.showError(
            "Merci de vérifier l'email que vous souhaitez inscrire",
            `L'email ${this.userEmail} semble factice ou invalide`
          );
        } else {
          this.notificationService.showErrorPleaseRetry(`L'email ${this.userEmail} n'a pu être ajouté à la newsletter`);
        }
        this.isLoading = false;
      },
    });
  }

  public handleUnsubscribe() {
    this.isLoading = true;
    this.newsletterService.unsubscribe(this.userEmail).subscribe({
      next: (result) => {
        this.notificationService.showSuccess(`L'email ${result.email} a bien été retiré à la newsletter`);
        this.isSubscribed = false;
        this.isLoading = false;
      },
      error: (error) => {
        if (error.status === 404) {
          this.notificationService.showError(
            "Merci de vérifier l'email que vous souhaitez désinscrire",
            `L'email ${this.userEmail} n'est pas inscrit à la newsletter`
          );
        } else {
          this.notificationService.showErrorPleaseRetry(
            `L'email ${this.userEmail} n'a pu être retiré de la newsletter`
          );
        }
        this.isLoading = false;
      },
    });
  }
}
